@@ -7,7 +7,7 @@ import os
 import io
 import sys
 import gzip
-import bz2file
+import bz2
 from collections.abc import MutableMapping
 
 try:
@@ -58,7 +58,7 @@ class Open(object):
                 compression = ftype
                 break
         if compression == 'bz2':
-            sequencefile = bz2file.BZ2File(filename=bufferedfile)
+            sequencefile = bz2.BZ2File(filename=bufferedfile)
             peek = sequencefile.peek(1)
         elif compression == 'gz':
             if not bufferedfile.seekable():
@@ -67,6 +67,7 @@ class Open(object):
                                  "through zcat first")
             peek = gzip.GzipFile(filename=filename).read(1)
             sequencefile = gzip.GzipFile(filename=filename)
+            bufferedfile.close()
         else:
             peek = bufferedfile.peek(1)
             sequencefile = bufferedfile
@@ -117,6 +118,7 @@ class ScreedDB(MutableMapping):
     """
 
     def __init__(self, filepath):
+        self._db = None
         try:
             sqlite3
         except NameError:
@@ -124,7 +126,6 @@ class ScreedDB(MutableMapping):
                             "functionality, but is not installed.")
 
         self._filepath = filepath
-        self._db = None
         if not self._filepath.endswith(DBConstants.fileExtension):
             self._filepath += DBConstants.fileExtension
 
